@@ -1,7 +1,11 @@
 /* Machine-specific elf macros for ARM.  */
 
 #define ELFCLASSM	ELFCLASS32
+#ifdef __ARMEB__
+#define ELFDATAM	ELFDATA2MSB
+#else
 #define ELFDATAM	ELFDATA2LSB
+#endif
 
 #define MATCH_MACHINE(x)  (x == EM_ARM)
 
