@@ -39,8 +39,8 @@ typedef int (*xftw_func_t)(const char *, const struct stat *);
 extern int xftw(const char *directory, xftw_func_t);
 
 /* Error logging */
-extern int log;
-extern int errors;
+extern int logging;
+extern int error_count;
 extern const char *error_file;
 
 extern int flag_verbose;
