@@ -275,7 +275,7 @@ static int add_symbols_from(struct obj_file *f, int idx,
 		if (strncmp((char *)s->name, "GPLONLY_", 8) == 0) {
 			gplonly_seen = 1;
 			if (gpl)
-				((char *)s->name) += 8;
+				s->name = ((char *)s->name) + 8;
 			else
 				continue;
 		}
@@ -648,9 +648,7 @@ static int create_module_ksymtab(struct obj_file *f)
 		for (i = 0; i < n_module_stat; ++i)
 			if (module_stat[i].status /* used */) {
 				dep->dep = module_stat[i].addr;
-#ifdef ARCH_ppc64
-				dep->dep |= ppc64_module_base (f);
-#endif
+				dep->dep |= arch_module_base (f);
 				obj_symbol_patch(f, sec->idx, (char *) &dep->ref - sec->contents, tm);
 				dep->next_ref = 0;
 				++dep;
@@ -1681,7 +1679,7 @@ int INSMOD_MAIN(int argc, char **argv)
 	error_file = "insmod";
 
 	/* To handle repeated calls from combined modprobe */
-	errors = optind = 0;
+	error_count = optind = 0;
 
 	/* Process the command line.  */
 	while ((o = getopt_long(argc, argv, "fhkLmnpqrsSvVxXyYNe:o:O:P:R:",
@@ -2066,7 +2064,7 @@ int INSMOD_MAIN(int argc, char **argv)
 		goto out;
 	/**** No symbols or sections to be changed after kallsyms above ***/
 
-	if (errors)
+	if (error_count)
 		goto out;
 
 	/* If we were just checking, we made it.  */
@@ -2083,9 +2081,7 @@ int INSMOD_MAIN(int argc, char **argv)
 	} else {
 		errno = 0;
 		m_addr = create_module(m_name, m_size);
-#ifdef	ARCH_ppc64
-		m_addr |= ppc64_module_base (f);
-#endif
+		m_addr |= arch_module_base (f);
 		switch (errno) {
 		case 0:
 			break;
@@ -2127,10 +2123,10 @@ int INSMOD_MAIN(int argc, char **argv)
 		test_read.m.read_start = m_addr + sizeof(struct module);
 		test_read.m.read_end = test_read.m.read_start + sizeof(test_read.data);
 		if (sys_init_module(m_name, (struct module *) &test_read)) {
-			int old_errors = errors;
+			int old_errors = error_count;
 			error("has persistent data but the kernel is too old to support it."
 				"  Expect errors during rmmod as well");
-			errors = old_errors;
+			error_count = old_errors;
 		}
 	}
 
@@ -2156,7 +2152,7 @@ int INSMOD_MAIN(int argc, char **argv)
 #else
 	init_module(m_name, f, m_size, blob_name, noload, flag_load_map);
 #endif
-	if (errors) {
+	if (error_count) {
 		if (!noload)
 			delete_module(m_name);
 		goto out;
