@@ -313,6 +313,11 @@ static DESC *build_desc(const char *name, const char *objname, int allow_alias)
 	desc->autoclean = 1;
 
 	for (p = name; p; p = allow_alias ? any_alias(p) : NULL) {
+		if (++aliases > 1000) {		/* Arbitrary limit on alias loop */
+			allow_alias = 0;
+			fprintf(stderr, "modprobe: alias loop detected on %s\n", name);
+			break;
+		}
 		if (strcmp(p, "off") == 0) {
 			desc->objkey = NULL;
 			break;
@@ -336,11 +341,6 @@ static DESC *build_desc(const char *name, const char *objname, int allow_alias)
 				}
 			}
 		}
-		if (++aliases > 1000) {		/* Arbitrary limit on alias loop */
-			allow_alias = 0;
-			fprintf(stderr, "modprobe: alias loop detected on %s\n", name);
-			break;
-		}
 	}
 	if (!desc->kname)
 		desc->kname = desc->objkey;
@@ -776,7 +776,8 @@ static int read_depfile(void)
 	struct stat statbuf;
 	int ret = 0;
 	int line_no;
-	char buf[3000];
+	int sizebuf;
+	char *buf = NULL;
 	const char *depfile = gen_file[GEN_DEPFILE].name;
 
 	if ((fin = fopen(depfile, "r")) == NULL) {
@@ -794,9 +795,9 @@ static int read_depfile(void)
 			config_file, depfile);
 #endif
 
-	while (fgets_strip(buf, sizeof(buf) - 1, fin, &line_no) != NULL) {
+	while (fgets_strip(&buf, &sizebuf, fin, &line_no) != NULL) {
 		NODE *nod;
-		char line[sizeof(buf)];
+		char line[sizebuf];
 		char *pt;
 		char *modname;
 		int len = strlen(buf);
@@ -1022,7 +1023,7 @@ static int insmod(DESC *desc, LINK **new_in_kernel, char *options[])
 		if (quiet)
 			my_argv[my_argc++] = "-q";
 
-		if (log)
+		if (logging)
 			my_argv[my_argc++] = "-s";
 
 		if (insmod_opt) {
@@ -1379,9 +1380,14 @@ static int modprobe_fromlist(int argc, char *argv[], char *type, int loadall)
 			do {
 				desc = NULL;
 				obj = g->pathv[alt];
-				ret = probe_stack(stripo(g->pathv[alt]), obj, options, &desc, &error_name);
-				if (ret >= -1) /* Some success */
-					++loaded;
+				if ( obj != NULL ) {
+					ret = probe_stack(stripo(g->pathv[alt]), obj, options, &desc, &error_name);
+					if (ret >= -1) /* Some success */
+						++loaded;
+				} else {
+					ret = -2;
+					error_name = NULL;
+				}
 			} while (++alt < g->pathc && (ret < -1 || loadall));
 		} else if ((g = any_probe_list(name))) {
 			ret = modprobe_fromlist(g->pathc, g->pathv, NULL, 0);
@@ -1420,7 +1426,7 @@ static int modprobe_fromlist(int argc, char *argv[], char *type, int loadall)
 	if (ret == -2) {
 		if (error_name && error_name != name)
 			error("Can't locate module %s which is needed for %s", error_name, name);
-		else
+		else if (!quiet)
 			error("Can't locate module %s", name);
 	}
 	else
