@@ -104,6 +104,7 @@ arch_apply_relocation (struct obj_file *f,
 
   unsigned int *iloc = (unsigned int *)(targsec->contents + rel->r_offset);
   unsigned short *sloc = (unsigned short *)iloc;
+  unsigned char *cloc = (unsigned char *)iloc;
   Elf64_Addr dot = targsec->header.sh_addr + rel->r_offset;
   Elf64_Addr gp = af->got->header.sh_addr + 0x8000;
   unsigned long tmp;
@@ -232,7 +233,7 @@ arch_apply_relocation (struct obj_file *f,
       if ((Elf64_Sxword)v >= 0x80000000
       	  || (Elf64_Sxword)v < -(Elf64_Sxword)0x80000000)
 	ret = obj_reloc_overflow;
-      *iloc = v;
+      memcpy(cloc, &v, sizeof(Elf64_Addr));
       break;
 
     default:
