@@ -52,7 +52,11 @@ char *aliaslist[] =
 	"binfmt--310 binfmt_java",
 
 	"block-major-1 rd",
+#if defined(__s390__) || defined(__s390x__) || defined(__ia64__) || defined(__powerpc__)
+	"block-major-2 off",
+#else
 	"block-major-2 floppy",
+#endif
 	"block-major-3 ide-probe-mod",
 	"block-major-7 loop",
 	"block-major-8 sd_mod",
@@ -86,7 +90,7 @@ char *aliaslist[] =
 	"block-major-90 ide-probe-mod",
 	"block-major-91 ide-probe-mod",
 	"block-major-93 nftl",		/* from David Woodhouse <dwmw2@infradead.org> */
-	"block-major-97 pg",
+	"block-major-113 viocd",
 
 #if !defined(__s390__) && !defined(__s390x__)
 	"char-major-4 serial",
@@ -107,6 +111,7 @@ char *aliaslist[] =
 					/* /dev/sunmouse Sun mouse */
 					/* /dev/beep Fancy beep device */
 					/* /dev/modreq Kernel module load request */
+	"char-major-10-116 snd",	
 	"char-major-10-130 wdt",	/* /dev/watchdog Watchdog timer port */
 	"char-major-10-131 wdt",	/* /dev/temperature Machine internal temperature */
 					/* /dev/hwtrap Hardware fault trap */
@@ -116,10 +121,16 @@ char *aliaslist[] =
 	"char-major-10-144 nvram",	/* from Tigran Aivazian <tigran@sco.COM> */
 	"char-major-10-157 applicom",	/* from David Woodhouse <dwmw2@infradead.org> */
 	"char-major-10-175 agpgart",    /* /dev/agpgart GART AGP mapping access */
+	"char-major-10-181 toshiba",	
+	"char-major-10-183 hw_random",	
 	"char-major-10-184 microcode",	/* Tigran Aivazian <tigran@veritas.com> */
+	"char-major-10-187 irnet",	
+	"char-major-10-189 ussp",	
 	"char-major-10-200 tun",	/* Universal TUN/TAP device driver */
+	"char-major-10-250 hci_vhci",
 
 	"char-major-13 input",
+	"char-major-13-0 joydev",
 	"char-major-13-32 mousedev",
 	"char-major-14 soundcore",
 	"char-major-19 cyclades",
@@ -127,7 +138,7 @@ char *aliaslist[] =
 	"char-major-21 sg",
 	"char-major-22 pcxx", /* ?? */
 	"char-major-23 pcxx", /* ?? */
-	"char-major-27 ftape",
+	"char-major-27 zftape",
 	"char-major-34 scc",
 	"char-major-35 tclmidi",
 	"char-major-36 netlink",
@@ -139,6 +150,7 @@ char *aliaslist[] =
 	"char-major-63 kdebug",
 	"char-major-90 mtdchar",	/* from David Woodhouse <dwmw2@infradead.org> */
 	"char-major-96 pt",
+	"char-major-97 pg",
 	"char-major-99 ppdev",
 	"char-major-107 3dfx", /* from Tigran Aivazian <tigran@sco.COM> */
 	"char-major-108 ppp_generic",
@@ -148,6 +160,22 @@ char *aliaslist[] =
 	"char-major-195 NVdriver",
 	"char-major-200 vxspec",
 	"char-major-206 osst",  /* OnStream SCSI tape */
+	"char-major-216 rfcomm",
+
+        /* agpgart like 2.6 */
+	"ali-agp agpgart",
+	"ati-agp agpgart",
+	"amd-k7-agp agpgart",
+	"amd64-agp agpgart",
+	"alpha-agp agpgart",
+	"hp-agp agpgart",
+	"i460-agp agpgart",
+	"intel-agp agpgart",
+	"nvidia-agp agpgart",
+	"sis-agp agpgart",
+	"sworks-agp agpgart",
+	"uninorth-agp agpgart",
+	"via-agp agpgart",
 
 	"dos msdos",
 	"dummy0 dummy",
@@ -170,10 +198,18 @@ char *aliaslist[] =
 				/* PF_AAL5	8  Reserved for Werner's ATM */
 				/* PF_X25	9  Reserved for X.25 project */
 	"net-pf-10 off",	/* PF_INET6	10 IP version 6 */
+	"net-pf-15 af_key",	/* PF_KEY       15 Key Management API */
 
 	/* next two from <dairiki@matthews.dairiki.org>  Thanks! */
 	"net-pf-17 af_packet",
 	"net-pf-19 off",	/* acorn econet */
+	"net-pf-20 atm",
+	"net-pf-23 irda",
+	"net-pf-24 pppoe",
+	"net-pf-25 wanrouter",
+	"net-pf-26 llc",
+	
+	"net-pf-31 bluez",
 
 	"netalias-2 ip_alias",
 
@@ -187,6 +223,15 @@ char *aliaslist[] =
 	"irda-dongle-5 litelink",
 	"irda-dongle-6 airport",
 	"irda-dongle-7 old_belkin",
+	 
+	"bt-proto-0 l2cap",
+	"bt-proto-2 sco",
+	"bt-proto-3 rfcomm",
+	"bt-proto-4 bnep",
+	"bt-proto-5 cmtp",
+	"bt-proto-6 hidp",
+	"bt-proto-7 avdtp",
+
 
 	"plip0 plip",
 	"plip1 plip",
@@ -211,10 +256,12 @@ char *aliaslist[] =
 	"tty-ldisc-3 ppp_async",
 	"tty-ldisc-11 irtty", /* IrDA over a normal serial port, or a serial port compatible IrDA port */
 	"tty-ldisc-14 ppp_synctty",
+	"tty-ldisc-15 hci_uart",
 	"ppp-compress-18 ppp_mppe",
 	"ppp-compress-21 bsd_comp",
 	"ppp-compress-24 ppp_deflate",
 	"ppp-compress-26 ppp_deflate",
+        "ppp ppp_async", /* for 2.4 */
 
 #ifndef __sparc__
 	"parport_lowlevel parport_pc",
@@ -224,6 +271,18 @@ char *aliaslist[] =
 
 	"usbdevfs usbcore",
 
+	"xfrm-type-2-50 esp4",
+	"xfrm-type-2-51 ah4",
+	"xfrm-type-2-108 ipcomp",
+	"xfrm-type-10-50 esp6",
+	"xfrm-type-10-51 ah6",
+	"xfrm-type-10-108 ipcomp6",
+
+	"cipher_null crypto_null",
+	"digest_null crypto_null",
+	"compress_null crypto_null",
+	"sha384 sha512",
+
 	NULL			/* marks the end of the list! */
 };
 
@@ -246,9 +305,6 @@ char *optlist[] =
  */
 char *above[] =
 {
-	"hid keybdev mousedev",
-	"usbmouse hid",
-	"wacom evdev",
 	NULL			/* marks the end of the list! */
 };
 
@@ -259,7 +315,6 @@ char *above[] =
  */
 char *below[] =
 {
-	"ov518_decomp ov511",
 	NULL			/* marks the end of the list! */
 };
 
